@@ -4,13 +4,13 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.003005';
+our $VERSION = '0.003006';
 
 use Moose;
 
 extends 'Throwable::Error';
 
-__PACKAGE__->meta()->make_immutable();
+__PACKAGE__->meta()->make_immutable( inline_constructor => 0 );
 
 1;
 
@@ -26,7 +26,7 @@ Stepford::Error - A Stepford exception object
 
 =head1 VERSION
 
-version 0.003005
+version 0.003006
 
 =head1 DESCRIPTION
 
@@ -39,7 +39,7 @@ Dave Rolsky <drolsky@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by MaxMind, Inc..
+This software is copyright (c) 2016 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
